![LOGO](/images/logo.png)

# containers-sugar

Simplify the usage of containers


* License: BSD 3 Clause
* Documentation: https://containers-sugar.github.io


## Features

* TODO

## Credits

This package was created with Cookiecutter and the
[osl-incubator/cookiecutter-python](https://github.com/osl-incubator/cookiecutter-python)
project template.
